@@ -16,6 +16,7 @@ from __future__ import with_statement
 
 import base64
 import copy
+import json
 import os
 import re
 import shutil
@@ -35,64 +36,13 @@ from selenium.common.exceptions import WebDriverException
 
 
 WEBDRIVER_EXT = "webdriver.xpi"
+WEBDRIVER_PREFERENCES = "webdriver_prefs.json"
 EXTENSION_NAME = "fxdriver@googlecode.com"
 
 class FirefoxProfile(object):
 
     ANONYMOUS_PROFILE_NAME   = "WEBDRIVER_ANONYMOUS_PROFILE"
-    DEFAULT_PREFERENCES = {
-        "app.update.auto": "false",
-        "app.update.enabled": "false",
-        "browser.download.manager.showWhenStarting": "false",
-        "browser.EULA.override": "true",
-        "browser.EULA.3.accepted": "true",
-        "browser.link.open_external": "2",
-        "browser.link.open_newwindow": "2",
-        "browser.offline": "false",
-        "browser.safebrowsing.enabled": "false",
-        "browser.search.update": "false",
-        "extensions.blocklist.enabled": "false",
-        "browser.sessionstore.resume_from_crash": "false",
-        "browser.shell.checkDefaultBrowser": "false",
-        "browser.tabs.warnOnClose": "false",
-        "browser.tabs.warnOnOpen": "false",
-        "browser.startup.page": "0",
-        "browser.safebrowsing.malware.enabled": "false",
-        "startup.homepage_welcome_url": "\"about:blank\"",
-        "devtools.errorconsole.enabled": "true",
-        "dom.disable_open_during_load": "false",
-        "extensions.autoDisableScopes" : 10,
-        "extensions.logging.enabled": "true",
-        "extensions.update.enabled": "false",
-        "extensions.update.notifyUser": "false",
-        "network.manage-offline-status": "false",
-        "network.http.max-connections-per-server": "10",
-        "network.http.phishy-userpass-length": "255",
-        "offline-apps.allow_by_default": "true",
-        "prompts.tab_modal.enabled": "false",
-        "security.fileuri.origin_policy": "3",
-        "security.fileuri.strict_origin_policy": "false",
-        "security.warn_entering_secure": "false",
-        "security.warn_entering_secure.show_once": "false",
-        "security.warn_entering_weak": "false",
-        "security.warn_entering_weak.show_once": "false",
-        "security.warn_leaving_secure": "false",
-        "security.warn_leaving_secure.show_once": "false",
-        "security.warn_submit_insecure": "false",
-        "security.warn_viewing_mixed": "false",
-        "security.warn_viewing_mixed.show_once": "false",
-        "signon.rememberSignons": "false",
-        "toolkit.networkmanager.disable": "true",
-        "toolkit.telemetry.enabled": "false",
-        "toolkit.telemetry.prompted": "2",
-        "toolkit.telemetry.rejected": "true",
-        "javascript.options.showInConsole": "true",
-        "browser.dom.window.dump.enabled": "true",
-        "webdriver_accept_untrusted_certs": "true",
-        "webdriver_enable_native_events": "true",
-        "webdriver_assume_untrusted_issuer": "true",
-        "dom.max_script_run_time": "30",
-        }
+    DEFAULT_PREFERENCES = None
 
     def __init__(self,profile_directory=None):
         """
@@ -103,8 +53,14 @@ class FirefoxProfile(object):
            This defaults to None and will create a new
            directory when object is created.
         """
+        if not FirefoxProfile.DEFAULT_PREFERENCES:
+            with open(os.path.join(os.path.dirname(__file__),
+                                   WEBDRIVER_PREFERENCES)) as default_prefs:
+                FirefoxProfile.DEFAULT_PREFERENCES = json.load(default_prefs)
+
         self.default_preferences = copy.deepcopy(
-            FirefoxProfile.DEFAULT_PREFERENCES)
+            FirefoxProfile.DEFAULT_PREFERENCES['mutable'])
+        self.native_events_enabled = True
         self.profile_dir = profile_directory
         self.tempfolder = None
         if self.profile_dir is None:
@@ -116,7 +72,7 @@ class FirefoxProfile(object):
             shutil.copytree(self.profile_dir, newprof,
                 ignore=shutil.ignore_patterns("parent.lock", "lock", ".parentlock"))
             self.profile_dir = newprof
-            self._read_existing_userjs()
+            self._read_existing_userjs(os.path.join(self.profile_dir, "user.js"))
         self.extensionsDir = os.path.join(self.profile_dir, "extensions")
         self.userPrefs = os.path.join(self.profile_dir, "user.js")
 
@@ -125,24 +81,14 @@ class FirefoxProfile(object):
         """
         sets the preference that we want in the profile.
         """
-        clean_value = ''
-        if value is True:
-            clean_value = 'true'
-        elif value is False:
-            clean_value = 'false'
-        elif isinstance(value, bytes):
-            clean_value = '"%s"' % value.decode('utf-8')
-        elif isinstance(value, str): # unicode
-            clean_value = '"%s"' % value
-        else:
-            clean_value = str(int(value))
-
-        self.default_preferences[key] = clean_value
+        self.default_preferences[key] = value
 
     def add_extension(self, extension=WEBDRIVER_EXT):
         self._install_extension(extension)
 
     def update_preferences(self):
+        for key, value in FirefoxProfile.DEFAULT_PREFERENCES['frozen'].items():
+            self.default_preferences[key] = value
         self._write_user_prefs(self.default_preferences)
 
     #Properties
@@ -179,8 +125,7 @@ class FirefoxProfile(object):
 
     @property
     def accept_untrusted_certs(self):
-        return self._santise_pref(
-            self.default_preferences["webdriver_accept_untrusted_certs"])
+        return self.default_preferences["webdriver_accept_untrusted_certs"]
 
     @accept_untrusted_certs.setter
     def accept_untrusted_certs(self, value):
@@ -190,7 +135,7 @@ class FirefoxProfile(object):
 
     @property
     def assume_untrusted_cert_issuer(self):
-        return self._santise_pref(self.default_preferences["webdriver_assume_untrusted_issuer"])
+        return self.default_preferences["webdriver_assume_untrusted_issuer"]
 
     @assume_untrusted_cert_issuer.setter
     def assume_untrusted_cert_issuer(self, value):
@@ -201,7 +146,7 @@ class FirefoxProfile(object):
 
     @property
     def native_events_enabled(self):
-        return self._santise_pref(self.default_preferences['webdriver_enable_native_events'])
+        return self.default_preferences['webdriver_enable_native_events']
 
     @native_events_enabled.setter
     def native_events_enabled(self, value):
@@ -246,15 +191,6 @@ class FirefoxProfile(object):
         elif proxy.proxy_type is ProxyType.PAC:
             self.set_preference("network.proxy.autoconfig_url", proxy.proxy_autoconfig_url)
 
-    #Private Methods
-    def _santise_pref(self, item):
-        if item == 'true':
-            return True
-        elif item == 'false':
-            return False
-        else:
-            return item
-
     def _set_manual_proxy_preference(self, key, setting):
         if setting is None or setting is '':
             return
@@ -276,16 +212,18 @@ class FirefoxProfile(object):
         """
         with open(self.userPrefs, "w") as f:
             for key, value in user_prefs.items():
-                f.write('user_pref("%s", %s);\n' % (key, value))
+                f.write('user_pref("%s", %s);\n' % (key, json.dumps(value)))
 
-    def _read_existing_userjs(self):
-        userjs_path = os.path.join(self.profile_dir, 'user.js')
+    def _read_existing_userjs(self, userjs):
         PREF_RE = re.compile(r'user_pref\("(.*)",\s(.*)\)')
         try:
-            with open(userjs_path) as f:
+            with open(userjs) as f:
                 for usr in f:
                     matches = re.search(PREF_RE, usr)
-                    self.default_preferences[matches.group(1)] = matches.group(2)
+                    try:
+                      self.default_preferences[matches.group(1)] = json.loads(matches.group(2))
+                    except:
+                      print "(skipping) failed to json.loads existing prefernce:", matches.group(1), matches.group(2)
         except:
             # The profile given hasn't had any changes made, i.e no users.js
             pass
